Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/desktop.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMariana Meireles <mariana@psychonautgirl.space>2019-10-27 18:12:07 +0300
committerMariana Meireles <mariana@psychonautgirl.space>2019-10-27 18:16:10 +0300
commitf6feaf5bde77deeff245f5516d010b91b6ce942d (patch)
tree46ec401d08cde0d808359c4754015f393f582338
parentf2ebb4480700ab1283de2a26744a96d105c8217a (diff)
Add a new image to edit the ignore list. Remove the folder image.feature/add-edit-button
Signed-off-by: Mariana Meireles <mariana@psychonautgirl.space>
-rw-r--r--client.qrc2
-rw-r--r--resources/folder.svg1
-rw-r--r--resources/rename.pngbin0 -> 16561 bytes
-rw-r--r--src/gui/activityitemdelegate.cpp6
4 files changed, 4 insertions, 5 deletions
diff --git a/client.qrc b/client.qrc
index f9952965a..1d27ffd92 100644
--- a/client.qrc
+++ b/client.qrc
@@ -19,7 +19,7 @@
<file>resources/files.svg</file>
<file>resources/state-error.svg</file>
<file>resources/state-warning.svg</file>
- <file>resources/folder.svg</file>
+ <file>resources/rename.png</file>
<file>resources/network.svg</file>
<file>resources/settings.svg</file>
<file>resources/public-white.svg</file>
diff --git a/resources/folder.svg b/resources/folder.svg
deleted file mode 100644
index c311e426b..000000000
--- a/resources/folder.svg
+++ /dev/null
@@ -1 +0,0 @@
-<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 16 16" width="16" version="1.1" height="16"><path fill="#0082c9" d="m1.5 2c-0.25 0-0.5 0.25-0.5 0.5v11c0 0.26 0.24 0.5 0.5 0.5h13c0.26 0 0.5-0.241 0.5-0.5v-9c0-0.25-0.25-0.5-0.5-0.5h-6.5l-2-2z"/></svg>
diff --git a/resources/rename.png b/resources/rename.png
new file mode 100644
index 000000000..02e364d93
--- /dev/null
+++ b/resources/rename.png
Binary files differ
diff --git a/src/gui/activityitemdelegate.cpp b/src/gui/activityitemdelegate.cpp
index 5df0f8706..d3df8256d 100644
--- a/src/gui/activityitemdelegate.cpp
+++ b/src/gui/activityitemdelegate.cpp
@@ -209,7 +209,7 @@ void ActivityItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
} else if(activityType == Activity::SyncResultType){
// Secondary will be 'open file manager' with the folder icon
- secondaryButton.icon = QIcon(QLatin1String(":/client/resources/folder.svg"));
+ secondaryButton.icon = QIcon(QLatin1String(":/client/resources/rename.png"));
secondaryButton.iconSize = QSize(iconSize, iconSize);
// Primary button will be 'open browser'
@@ -234,8 +234,8 @@ void ActivityItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &
_secondaryButtonWidth = secondaryButton.rect.size().width();
_spaceBetweenButtons = secondaryButton.rect.left() - primaryButton.rect.right();
- // Secondary will be 'open file manager' with the folder icon
- secondaryButton.icon = QIcon(QLatin1String(":/client/resources/folder.svg"));
+ // Secondary will be 'open file manager' with the rename icon
+ secondaryButton.icon = QIcon(QLatin1String(":/client/resources/rename.png"));
secondaryButton.iconSize = QSize(iconSize, iconSize);
// No primary button on this case